﻿using UnityEngine;
using System.Collections.Generic;
using System.Linq;

public class AudioManager : MonoBehaviour {
	[SerializeField]
	private BeatHit _beatHit;

	[SerializeField]
	private float _volumeThreshold = 0.01f;

	[SerializeField]
	private AudioSource _audioSourceMain;
	[SerializeField]
	private AudioSource _audioSourceThreshold;

	float _updateStep = 0.1f;
	int _sampleDataLength = 1024;

	private float _updateTime = 0f;
	private float[] _sampleData;

	void Awake () {

		if (!_audioSourceThreshold) {
			Debug.LogError(GetType() + "No audioSource set for volume detection.");
		}
		_sampleData = new float[_sampleDataLength];
	}

	void Update(){

		_updateTime += Time.deltaTime;
		if (_updateTime >= _updateStep) {
			_updateTime = 0f;
			_audioSourceThreshold.clip.GetData(_sampleData, _audioSourceThreshold.timeSamples); //I read 1024 samples, which is about 80 ms on a 44khz stereo clip, beginning at the current sample position of the clip.

			var samples = _sampleData.ToArray ();
			for (int i=0; i< samples.Count(); i++) {
				samples[i] = Mathf.Abs(samples[i]);
			}
			float volume = samples.Average ();

			if (volume > _volumeThreshold) {
				_beatHit.Triggered = true;
				Debug.DrawLine (Vector3.zero, new Vector3 (0f, volume * 100f, 0f), Color.red); 
			} else {
				Debug.DrawLine (Vector3.zero, new Vector3 (0f, volume * 100f, 0f), Color.green);
			}
		}

		Debug.DrawLine(new Vector2(-1f, _volumeThreshold * 100f), new Vector2(1f, _volumeThreshold * 100f), Color.blue);
	}
}
