﻿using UnityEngine;
using System.Collections;

public class Huey : MonoBehaviour {
	[SerializeField]
	SpriteRenderer _handLeft;

	[SerializeField]
	Sprite _fist;
	[SerializeField]
	Sprite _palm;

	[SerializeField]
	SpriteRenderer _handRight = null;

	[SerializeField]
	Player _player;

	[SerializeField]
	GameObject _bulletWave;

	float _yPos = 3.5f;

	float _yPosAway = 10f;

	bool _follow = false;
	bool _attack = false;
	bool _prepareStopAttack = false;

	SpriteRenderer _attackingHand;

	bool _shakeFist = false;

	void Awake(){
		Invoke ("EnterHuey", 10f);

		_handLeft.sprite = _fist;
		_handRight.sprite = _fist;
	}

	void Update()
	{
		if (_player.gameObject.activeSelf == false) {
			StopAttack (true);
		}

		_handLeft.transform.localScale = Vector3.Lerp(_handLeft.transform.localScale, Vector3.one * 2, Time.deltaTime * 5f);
		_handRight.transform.localScale = Vector3.Lerp(_handRight.transform.localScale, Vector3.one * 2, Time.deltaTime * 5f);

		if(_handLeft != _attackingHand)
			_handLeft.transform.rotation = Quaternion.identity;

		if(_handRight != _attackingHand)
			_handRight.transform.rotation = Quaternion.identity;

		if (_attackingHand != null) {
			if(_shakeFist)
				_attackingHand.transform.rotation = Quaternion.Euler (0f, 0f, Random.Range (-20f, 20f));
			_attackingHand.color = Color.Lerp (_attackingHand.color, Color.red, Time.deltaTime * 2f);
		}

		if(_handLeft != _attackingHand)
			_handLeft.color = Color.Lerp(_handLeft.color, Color.white, Time.deltaTime*5f);

		if(_handRight != _attackingHand)
		_handRight.color = Color.Lerp(_handRight.color, Color.white, Time.deltaTime*5f);

		if (_follow) {
			transform.position = Vector3.Lerp (transform.position, new Vector3 (_player.transform.position.x, _yPos, 0f), 2f * Time.deltaTime);
		} else if (!_attack) {
			transform.position = Vector3.Lerp (transform.position, new Vector3 (0f, _yPosAway, 0f), 2f * Time.deltaTime);
		}
	}

	void EnterHuey()
	{
		if (_prepareStopAttack) {
			Invoke ("EnterHuey", 0.5f);
			_prepareStopAttack = false;
			return;
		}
		_follow = true;
		_attack = true;
		Invoke ("StartAttack", 4f);
	}

	void StartAttack()
	{
		_shakeFist = true;
		_follow = false;
		if (Random.Range (0f, 1f) > 0.5f)
			_attackingHand = _handLeft;
		else
			_attackingHand = _handRight;

		Invoke ("AttackWave", 2f);
	}

	void AttackWave()
	{
		_shakeFist = false;
		if (_attackingHand != null) {
			_attackingHand.transform.rotation = Quaternion.identity;
			_attackingHand.sprite = _palm;
			_attackingHand.transform.localScale *= 2.5f;
			Instantiate (_bulletWave, _attackingHand.transform.position, Quaternion.identity);
		}
		Invoke ("AttackCleanup", 1.0f);
	}

	void AttackCleanup()
	{
		_follow = true;
		if (_attackingHand != null) {
			_attackingHand.sprite = _fist;
		}
		_attackingHand = null;

		if (!_prepareStopAttack) {
			Invoke ("StartAttack", 4f);
		} else {
			Invoke ("Leave", 1f);
		}
	}

	public void StopAttack(bool shouldStop)
	{
		_prepareStopAttack = shouldStop;
	}

	void Leave(){
		_attack = false;
		_follow = false;
		_prepareStopAttack = false;
		Invoke ("EnterHuey", 10f);
	}
}
